#include "../include/fb.h"  // Header file for framebuffer functions
#include "../include/io.h"  // Include for outb function

#define FB_COLS 80         // Number of columns in the framebuffer
#define FB_ROWS 25         // Number of rows in the framebuffer
#define FB_ADDR 0xB8000    // Starting address of the framebuffer

// Function to clear the framebuffer
void fb_clear() {
    char *fb = (char *)FB_ADDR;
    for (int i = 0; i < FB_COLS * FB_ROWS; i++) {
        fb[i * 2] = ' ';      // Empty space
        fb[i * 2 + 1] = 0x07; // Default color (white on black)
    }
}

// Function to print a string to the framebuffer at a specific location
void fb_print(const char *str, unsigned short row, unsigned short col) {
    char *fb = (char *)FB_ADDR;
    unsigned short pos = (row * FB_COLS + col) * 2;  // Calculate position

    for (int i = 0; str[i] != '\0'; i++) {
        fb[pos + i * 2] = str[i];  // Write character
        fb[pos + i * 2 + 1] = 0x07;  // Default color
    }
}

// Function to set the cursor position
void fb_move(unsigned short row, unsigned short col) {
    unsigned short pos = row * FB_COLS + col;

    // Send the position to the VGA cursor registers
    outb(0x3D4, 0x0F);  // Low cursor byte
    outb(0x3D5, (unsigned char)(pos & 0xFF));
    outb(0x3D4, 0x0E);  // High cursor byte
    outb(0x3D5, (unsigned char)((pos >> 8) & 0xFF));
}
